@@ -100,7 +100,7 @@ find_skewness(carseats, value = TRUE)
 find_skewness(carseats, value = TRUE, thres = 0.1)
 
 ## ----resolving2, fig.align='center', fig.width = 7, fig.height = 5------------
-Advertising_log = transform(carseats$Advertising, method = "log")
+Advertising_log <- transform(carseats$Advertising, method = "log")
 
 # result of transformation
 head(Advertising_log)
